@@ -5,15 +5,15 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import aws_cdk.region_info._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-iam", "1.57.0", __name__[0:-6], "aws-iam@1.57.0.jsii.tgz"
+    "@aws-cdk/aws-iam", "1.64.0", __name__[0:-6], "aws-iam@1.64.0.jsii.tgz"
 )
 
 __all__ = [
